pype32.pype32.SectionHeaders

Package pype32 :: Module pype32 :: Class SectionHeaders |
[hide private]
[frames] | no frames]

# Class SectionHeaders

source code

    object --+
             |
          list --+
                 |
                SectionHeaders

SectionHeaders object.

Instance Methods | [hide private]
new empty list |
__init__(self, numberOfSectionHeaders=1, shouldPack=True) Array of SectionHeader objects. | source code
__str__(self) str(x) | source code
Inherited from `list`: `__add__`, `__contains__`, `__delitem__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__iadd__`, `__imul__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `__sizeof__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods | [hide private]
parse(readDataInstance, numberOfSectionHeaders) Returns a new SectionHeaders object. | source code

Class Variables | [hide private]
Inherited from `list`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, numberOfSectionHeaders=1, shouldPack=True) (Constructor) | source code
Array of SectionHeader objects. Parameters: `shouldPack` (bool) - (Optional) If set to `True`, the object will be packed. If set to `False`, the object won't be packed. `numberOfSectionHeaders` (int) - (Optional) The number of desired section headers. By default, this parameter is set to 1. Returns: new empty list Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### parse(readDataInstance, numberOfSectionHeaders) Static Method | source code
Returns a new SectionHeaders object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a SectionHeaders object. `numberOfSectionHeaders` (int) - The number of SectionHeader objects in the SectionHeaders instance.